/*** RFM12BPCmd.h ***/
//-----------------------------------------------
// Author: Torsten Knorr
// E-mail: create-soft@freenet.de
// copyright(C) 2016-2017 by Torsten Knorr
//-----------------------------------------------

 #ifndef __RFM12BP_CMD__
 #define __RFM12BP_CMD__ 1

//-----------------------------------------------
/*** 1. Configuration Setting Command ***/

// bit 15 14 13 12 11 10  9  8  7  6  5  4  3  2  1  0 POR
//      1  0  0  0  0  0  0  0 el ef b1 b0 x3 x2 x1 x0 8008h
 #define CMD_SET_CONF 0x8000

// [ el ] -> enables the internal TX-data register
 #define EN_TX_REG 0x0080

// [ ef ] -> enables the FIFO mode and RX-FIFO buffer
// ef == 0 -> DATA (pin 6) and DCLK (pin 7) are used for data and data clock output
 #define EN_RX_BUF 0x0040

// [ b1..b0 ] -> select band
// b1  b0 band[MHz]
// 0    0 Reserved
// 0    1 433
// 1    0 868
// 1    1 915
 #define FREQ_BAND_433 0x0010
 #define FREQ_BAND_868 0x0020
 #define FREQ_BAND_915 0x0030

// [ x3..x0 ] -> select crystal load capacitor
// X3 x2 x1 x0 load capacitor [pF]
//  0  0  0  0 8.5
//  0  0  0  1 9.0
//  0  0  1  0 9.5
//  0  0  1  1 10.0
// ...
//  1  1  1  0 15.5
//  1  1  1  1 16.0
 #define CAPACITOR_8_5  0x0000
 #define CAPACITOR_9    0x0001
 #define CAPACITOR_9_5  0x0002
 #define CAPACITOR_10   0x0003
 #define CAPACITOR_10_5 0x0004
 #define CAPACITOR_11   0x0005
 #define CAPACITOR_11_5 0x0006
 #define CAPACITOR_12   0x0007
 #define CAPACITOR_12_5 0x0008
 #define CAPACITOR_13   0x0009
 #define CAPACITOR_13_5 0x000A
 #define CAPACITOR_14   0x000B
 #define CAPACITOR_14_5 0x000C
 #define CAPACITOR_15   0x000D
 #define CAPACITOR_15_5 0x000E
 #define CAPACITOR_16   0x000F

//-----------------------------------------------
/*** 2. Power Management Command ***/

// bit 15 14 13 12 11 10  9  8  7   6  5  4  3  2  1  0 POR
//      1  0  0  0  0  0  1  0 er ebb et es ex eb ew dc 8208h
 #define CMD_SET_POWER 0x8200

// [ er ] -> enables the whole receiver chain RF front end, baseband, synthesizer, crystal oscillator
 #define EN_RX 0x0080

// [ ebb ] -> the receiver baseband circuit can be separately switched on
 #define EN_BB_CIRCUIT 0x0040

// [ et ] -> switches on the PLL, the power amplifier, synthesizer, crystal oscillator
// and starts the transmission (if TX register is enabled)
 #define EN_TX 0x0020

// [ es ] -> turns on the synthesizer
 #define EN_SYNTH 0x0010

// [ ex ] -> turns on the crystal oscillator
 #define EN_CRYSTAL 0x0008

// [ eb ] -> enables the low battery detector
 #define EN_LOW_BAT 0x0004

// [ ew ] -> enables the wake-up timer
 #define EN_WAKE_UP 0x0002

// [ dc ] -> disables the clock output pin
 #define DI_CLK_PIN 0x0001

//-----------------------------------------------
/*** 3. Frequency Setting Command ***/

// bit 15 14 13 12  11  10  9  8  7  6  5  4  3  2  1  0 POR
//      1  0  1  0 f11 f10 f9 f8 f7 f6 f5 f4 f3 f2 f1 f0 A680h
 #define CMD_SET_FREQ 0xA000

// [ f11..f0 ] -> Set operation frequency:
// 433band: Fc=430+F*0.0025 MHz
// 868band: Fc=860+F*0.0050 MHz
// 915band: Fc=900+F*0.0075 MHz
// Fc is carrier frequency and F is the frequency parameter.

// The 12-bit parameter F (bits f11 to f0) should be in the range
// of 96 and 3903. When F value sent is out of range, the
// previous value is kept. The synthesizer center frequency f0
// can be calculated as:
// f0 = 10 * C1 * (C2 + F / 4000) [MHz]
// The constants C1 and C2 are determined by the selected band as:
// Band [MHz] C1  C2
//  433        1  43
//  868        2  43
//  915        3  30

// Band     Minimum Frequency  MaximumFrequency  PLL Frequency Step
// 433 MHz  430.2400 MHz       439.7575 MHz      2.5 kHz
// 868 MHz  860.4800 MHz       879.5150 MHZ      5.0 kHz
// 915 MHz  900.7200 MHz       929.2725 MHz      7.5 kHz

// min. = 860.480 MHz =   96 = 0x0060
// max. = 879.515 MHz = 3903 = 0x0F3F
// Short Range Devices  (SRD)
// SRD  = 863 - 870 MHz 500 mW / ERP
// Allgemeinzuteilung von Frequenzen zur Nutzung durch Funkanwendungen
// mit geringer Reichweite fr nicht nher spezifizierte Anwendungen
// 869.4 - 869.65 MHz 500 mW / ERP, Duty Cycle < 10%
// band center = 869,525
// band width = 250 kHz
// max. frequency deviation 120 kHz
// frequency deviation = 45 kHz / 60 kHz
// min.             = 869.480/869.465 kHz / low bit
// center frequency = 869.525 1905
// max.             = 869.570/869.585 kHz / high bit
// Differently between  modules???
// #define FREQ_869_525 0x0778
// #define FREQ_869_525 0x0779

//-----------------------------------------------
/*** 4. Data Rate Command ***/

// bit 15 14 13 12 11 10  9  8  7  6  5  4  3  2  1  0 POR
//      1  1  0  0  0  1  1  0 cs r6 r5 r4 r3 r2 r1 r0 C623h
 #define CMD_SET_BR 0xC600

// [ cs ] -> Prescaler (1/8)
 #define EN_PRESCALER 0x0080

// [ r6..r0 ] -> set bit rate
// The actual bit rate in transmit mode and the expected bit rate of the received data stream
// in receive mode is determined by the 7-bit parameter R (bits r6 to r0) and bit cs.
// BR = 10000 / 29 / ( R + 1) / (1 + cs * 7) [kbps]

// In the receiver set R according to the next function:
// R = (10000 / 29 / (1 + cs * 7) / BR)  1, where BR is the expected bit rate in kbps.
// Appart from setting custom values, the standard bit rates from 600 bps to 115.2 kbps
// can be approximated with small error.

// 4.8 kbps
// 10000 / 29 / 4.8 - 1 = 70.839 ~ 71 = 0x47
 #define BIT_RATE_4_8 0x0047

// 2.4 kbps
// TX: 10000 / 29 / (2.4 + 1) / (1 + (cs * 7)) = 12.67 ~ 13 = 0x0D
// RX: (10000 / 29 / (1 + (cs * 7)) / 13) - 1  = 2.315 kbps
 #define BIT_RATE_2_4 (0x000D|EN_PRESCALER)

// 1.2 kbps~
// TX: 10000 / 29 / (1.2 + 1) / (1 + (cs * 7)) = 19.59 ~ 20 = 0x14
// RX: (10000 / 29 / (1 + (cs * 7)) / 20) - 1  = 1.155 kbps
 #define BIT_RATE_1_2 (0x0014|EN_PRESCALER)

// 0.6 kbps
// TX: 10000/ 29 / (0.6 + 1) / 8 = 26.93 ~ 27 = 0x1B
// RX: (10000 / 29 / 8 / 27) - 1 = 0.596 kbps
 #define BIT_RATE_0_6 (0x001B|EN_PRESCALER)

// Data rate accuracy requirements:
// Clock recovery in slow mode: dBR/BR < 1/(29  Nbit )
// Clock recovery in fast mode: dBR/BR < 3/(29  Nbit )

// BR is the bit rate set in the receiver and dBR is the bit rate difference between
// the transmitter and the receiver. Nbit is the maximum number of consecutive ones or
// zeros in the data stream. It is recommended for long data packets to include enough 1/0 and 0/1
// transitions, and to be careful to use the same division ratio in the receiver and in the transmitter.

//-----------------------------------------------
/*** 5. Receiver Control Command ***/

// bit 15 14 13 12 11  10  9  8  7  6  5  4  3  2  1  0 POR
//      1  0  0  1  0 P16 d1 d0 i2 i1 i0 g1 g0 r2 r1 r0 9080h
 #define CMD_RX_CONFIG 0x9000

// [ P16 ] -> select function of pin16
// P16 == 0 -> Interrupt input
// P16 == 1 -> VDI output
 #define PIN_16_INT 0x0000
 #define PIN_16_VDI 0x0400

// [ d1..d0 ] -> select VDI response time
// Fast mode: The VDI signal follows the level of the DQD signal.
// Medium mode: The VDI signal will be active when the CR_LOCK signal and either
// the DRSSI or the DQD signal is high. The valid data indicator will go low when
// either the CR_LOCK gets inactive or both of the DRSSI or DQD signals go low.
// Slow mode: The VDI signal will go high only if the DRSSI, DQD and the CR_LOCK
// (Clock Recovery Locked) signals present at the same time. It stays high until
// any of the abovementioned signals present; it will go low when all the three
// input signals are low.
// Always mode: VDI is connected to logic high permanently. It stays always high
// independently of the receiving parameters.
// d1  d0  Response
//  0   0  Fast
//  0   1  Medium
//  1   0  Slow
//  1   1  Always on
 #define VDI_FAST   0x0000
 #define VDI_MEDIUM 0x0100
 #define VDI_SLOW   0x0200
 #define VDI_ALWAYS 0x0300

// [ i2..i0 ] -> select baseband bandwidth
// i2 i1 i0  Baseband Bandwidth [kHz]
//  0  0  0  reserved
//  0  0  1  400
//  0  1  0  340
//  0  1  1  270
//  1  0  0  200
//  1  0  1  134
//  1  1  0  67
//  1  1  1  reserved
 #define BAND_WIDTH_R1  0b00000000
 #define BAND_WIDTH_400 0b00100000
 #define BAND_WIDTH_340 0b01000000
 #define BAND_WIDTH_270 0b01100000
 #define BAND_WIDTH_200 0b10000000
 #define BAND_WIDTH_134 0b10100000
 #define BAND_WIDTH_67  0b11000000
 #define BAND_WIDTH_R2  0b11100000

// [ g1..g0 ] -> select LNA gain
// g1  g0   LNA gain (dBm)
// 0   0     0
// 0   1    -6
// 1   0   -14
// 1   1   -20
 #define LNA_GAIN_0  0x0000
 #define LNA_GAIN_6  0x0008
 #define LNA_GAIN_14 0x0010
 #define LNA_GAIN_20 0x0018

// [ r2..r0 ] -> select DRSSI threshold (Digital Received Signal Strength Indication)
// The actual threshold is related to LNA setup:
// RSSIth = RSSIsetth + Gain-LNA.
//  r2  r1  r0  RSSIsetth [dBm]
//   0   0   0  -103
//   0   0   1   -97
//   0   1   0   -91
//   0   1   1   -85
//   1   0   0   -79
//   1   0   1   -73
//   1   1   0  Reserved
//   1   1   1  Reserved
 #define DRSSI_103 0x0000
 #define DRSSI_97  0x0001
 #define DRSSI_91  0x0002
 #define DRSSI_85  0x0003
 #define DRSSI_79  0x0004
 #define DRSSI_73  0x0005
 #define DRSSI_R1  0x0006
 #define DRSSI_R2  0x0007

//-----------------------------------------------
/*** 6. Data Filter Command ***/

// bit 15 14 13 12 11 10 9 8  7  6 5 4 3  2  1  0 POR
//      1  1  0  0  0  0 1 0 al ml 1 s 1 f2 f1 f0 C22Ch
 #define CMD_SET_FILTER 0xC228;

// [ al ] -> Clock recovery (CR) auto lock control
// al == 1 -> auto mode: the CR starts in fast mode, after locking it switches to slow mode.
// Bit 6 (ml) has no effect.
// al == 0 -> manual mode: the clock recovery mode is set by Bit 6 (ml)
 #define CLK_REC_AUTO   0x0080
 #define CLK_REC_MANUAL 0x0000

// [ ml ] -> Clock recovery lock control
// ml == 1 -> fast mode: fast attack and fast release (4 to 8-bit preamble (1010...) is recommended)
// ml == 0 -> slow mode: slow attack and slow release (12 to 16-bit preamble is recommended)
// Using the slow mode requires more accurate bit timing (see Data Rate Command).
 #define CLK_REC_FAST 0x0040
 #define CLK_REC_SLOW 0x0000

// [ s ] -> select data filter type
// s == 0 -> Digital: This is a digital realization of an analog RC filter followed
// by a comparator with hysteresis. The time constant is automatically adjusted
// to the bit rate defined by the Data Rate Command.
// Note: Bit rate cannot exceed 115 kpbs in this mode.
// s == 1 -> Analog RC filter: The demodulator output is fed to pin 7 over a 10 kOhm resistor.
// The filter cut-off frequency is set by the external capacitor connected to this pin and VSS.
 #define DIG_FILTER 0x0000
 #define ANA_FILTER 0x0010

// [ f2..f0 ] -> DQD threshold parameter
// The Data Quality Detector is a digital processing part of the radio, connected to the demodulator
// it is an indicator reporting the reception of an FSK modulated RF signal. It will work every time
// the receiver is on. Setting this parameter defines how clean incoming data stream would be stated
// as good data (valid FSK signal). If the internally calculated data quality value exceeds the DQD
// threshold parameter for five consecutive data bits for both the high and low periods, then the DQD
// signal goes high. The DQD parameter in the Data Filter Command should be chosen according to the
// following rules:
// The DQD parameter can be calculated with the following formula:
// DQD par = 4 x (deviation  TX-RXoffset ) / bit rate
// It should be larger than 4 because otherwise noise might be treated as a valid FSK signal
// The maximum value is 7.
 #define DQD_1 0x0001
 #define DQD_2 0x0002
 #define DQD_3 0x0003
 #define DQD_4 0x0004
 #define DQD_5 0x0005
 #define DQD_6 0x0006
 #define DQD_7 0x0007

//-----------------------------------------------
/*** 7. FIFO and Reset Mode Command ***/

// bit 15 14 13 12 11 10 9 8  7  6  5  4  3  2  1  0 POR
//      1  1  0  0  1  0 1 0 f3 f2 f1 f0 sp al ff dr CA80h
 #define CMD_FIFO_RESET 0xCA00

// [ f3..f0 ] -> Set FIFO interrupt level
// The FIFO generates INT when the number of received data bits reaches this level.
 #define FIFO_INT_LEVEL_8 0x0080

// [ sp ] -> Select the length of the synchron pattern
// The synchron pattern consists of one or two bytes depending on the sp bit.
// Byte1 is fixed 0x2D, Byte0 can be programmed by the Synchron Pattern Command.
// sp  Byte1     Byte2  (POR) Synchron Pattern (Byte1 + Byte2)
// 0   0x2D      0xD4    0x2DD4
// 1   Not used  0xD4    0xD4
 #define SYNC_PAT_2DD4 0x0000
 #define SYNC_PAT_D4   0x0008

// [ al ] -> select FIFO fill start condition
// al == 0 -> Sync-word
// al == 1 -> fill always
 #define FIFO_SYNC_WORD   0x0000
 #define FIFO_FILL_ALWAYS 0x0004

// [ ff ] -> Enable FIFO fill
 #define EN_FIFO_FILL 0x0002


// [ dr ] -> Disables the highly sensitive RESET mode.
// RESET is triggered when
// dr == 0 -> V dd below 1.6V, V dd glitch greater than 600mV (sensitive reset)
// dr == 1 -> V dd below 250mV (non-sensitive reset)
 #define EN_HI_SENS 0x0000
 #define DI_HI_SENS 0x0001

//-----------------------------------------------
/*** 8. Synchron pattern Command ***/

// bit 15 14 13 12 11 10 9 8  7  6  5  4  3  2  1  0 POR
//      1  1  0  0  1  1 1 0 b7 b6 b5 b4 b3 b2 b1 b0 CED4h
 #define CMD_SYNC_PAT 0xCE00

// This command is used to reprogram the synchronic pattern;

//-----------------------------------------------
/*** 9. Receiver FIFO Read Command ***/

// bit 15 14 13 12 11 10 9 8 7 6 5 4 3 2 1 0 POR
//      1  0  1  1  0  0 0 0 0 0 0 0 0 0 0 0 B000h
 #define CMD_FIFO_READ 0xB000

// This command is used to read FIFO data when FFIT interrupt generated.
// FIFO data output starts at 8th SCK period.

//-----------------------------------------------
/*** 10. AFC Command ***/

// bit 15 14 13 12 11 10 9 8  7  6   5   4  3  2  1  0 POR
//      1  1  0  0  0  1 0 0 a1 a0 rl1 rl0 st fi oe en C4F7h
 #define CMD_AFC 0xC400

// [ a1..a0 ] -> select AFC auto-mode
// a1  a0
// 0   0   Controlled by MCU
// 0   1   Run once at power on
// 1   0   Keep offset when VDI hi
// 1   1   Keeps independently from VDI
 #define AFC_MCU_CONTR   0x0000
 #define AFC_AT_POWER_ON 0x0040
 #define AFC_VDI_HI      0x0080
 #define AFC_INDEPEND    0x00C0

// [ rl1..rl0 ] -> select range limit
//  r1   r0  range(fres)
//   0    0  No restriction
//   0    1  +15..-16  433band: 2.5kHz
//   1    0   +7.. -8  868band: 5kHz
//   1    1   +3.. -4  915band: 7.5kHz
 #define RANGE_NO_LIMIT 0x0000
 #define RANGE_15_16    0x0010
 #define RANGE_7_8      0x0020
 #define RANGE_3_4      0x0030

// [ st ] -> Strobe edge, when st goes to high, the actual latest calculated frequency error
// is stored into the offset register of the AFC block.
 #define STORE_OFFSET 0x0008

// [ fi ] -> Switches the circuit to high accuracy (fine) mode. In this case, the processing time
// is about twice as long, but the measurement uncertainty is about half.
 #define EN_AFC_ACCURACY 0x0004

// [ oe ] -> Enables the frequency offset register. It allows the addition of the offset register
// to the frequency control word of the PLL.
 #define EN_AFC_REG 0x0002

// [ en ] -> Enables the calculation of the offset frequency by the AFC circuit.
 #define EN_AFC_FUNC 0x0001

//-----------------------------------------------
/*** 11. TX Configuration Control Command ***/

// bit 15 14 13 12 11 10 9  8  7  6  5  4 3  2  1  0 POR
//      1  0  0  1  1  0 0 mp m3 m2 m1 m0 0 p2 p1 p0 9800h
 #define CMD_TX_CONFIG 0x9800

// [ mp ] -> select modulation polarity
// mp == 0 -> data_bit_low  = freq. low
//            data_bit_high = freq. high
// mp == 1 -> data_bit_low  = freq high
//            data_bit_high = freq. low
 #define SEL_MOD_POL_NORMAL 0x0000
 #define SEL_MOD_POL_INVERT 0x0100

// [ m3..m0 ] -> select frequency deviation
//  m3  m2  m1  m0  frequency deviation [kHz]
//  0   0   0   0   15
//  0   0   0   1   30
//  0   0   1   0   45
// ...
//  1   1   0   1   210
//  1   1   1   0   225
//  1   1   1   1   240
 #define FREQ_DEVIATION_15  0x0000
 #define FREQ_DEVIATION_30  0x0010
 #define FREQ_DEVIATION_45  0x0020
 #define FREQ_DEVIATION_60  0x0030
 #define FREQ_DEVIATION_75  0x0040
 #define FREQ_DEVIATION_90  0x0050
 #define FREQ_DEVIATION_105 0x0060
 #define FREQ_DEVIATION_120 0x0070
 #define FREQ_DEVIATION_135 0x0080
 #define FREQ_DEVIATION_150 0x0090
 #define FREQ_DEVIATION_165 0x00A0
 #define FREQ_DEVIATION_180 0x00B0
 #define FREQ_DEVIATION_195 0x00C0
 #define FREQ_DEVIATION_210 0x00D0
 #define FREQ_DEVIATION_225 0x00E0
 #define FREQ_DEVIATION_240 0x00F0

// [ p2..p0 ] -> select output power
// p2  p1  p0   Output power[dBm]
//  0   0   0     0
//  0   0   1    -3
//  0   1   0    -6
//  0   1   1    -9
//  1   0   0   -12
//  1   0   1   -15
//  1   1   0   -18
//  1   1   1   -21
 #define OUTPUT_POWER_MAX 0x0000
 #define OUTPUT_POWER_3   0x0001
 #define OUTPUT_POWER_6   0x0002
 #define OUTPUT_POWER_9   0x0003
 #define OUTPUT_POWER_12  0x0004
 #define OUTPUT_POWER_15  0x0005
 #define OUTPUT_POWER_18  0x0006
 #define OUTPUT_POWER_21  0x0007

//-----------------------------------------------
/*** 12. PLL Setting Command ***/

// bit 15 14 13 12 11 10 9 8 7   6   5 4   3    2 1   0 POR
//      1  1  0  0  1  1 0 0 0 ob1 ob0 1 ddy ddit 1 bw0 CC77h
 #define CMD_SET_PLL 0xCC12

// Note1: For A0 version, the default value is CC67, it is necessary to use CC77
// instead of CC67 in the application program.
// NOTE2: For A1 version, you can use the default value CC77.

// [ ob1..ob0 ] -> Microcontroller output clock buffer rise and fall time control.
// The ob1-ob0 bits are changing the output drive current of the CLK pin.
// Higher current provides faster rise and fall times but can cause interference.
// ob1  ob0  Selected uC CLK frequency
//   0    0  5 or 10 MHz (recommended)
//   0    1  3.3 MHz
//   1    1  2.5 MHz or less
 #define MCU_CLK_TIME_10  0x0060
 #define MCU_CLK_TIME_3_3 0x0020
 #define MCU_CLK_TIME_2_5 0x0000


// [ ddy ] -> phase detector delay enable
 #define EN_PHASE_DELAY 0x0008

// [ ddit ] -> disables the dithering in the PLL loop
 #define DI_DITHERING_PLL 0x0004

// [ bw1..bw0 ] -> select PLL bandwidth
// bw1  bw0 Max bit rate [kbps]  Phase noise at 1MHz offset [dBc/Hz]
//   1  0   86.2                 -107
//   1  1   256                  -102
 #define PLL_MAX_BIT_RATE_86_2 0x0000
 #define PLL_MAX_BIT_RATE_256  0x0001

//-----------------------------------------------
/*** 13. Transmitter Register Write Command ***/

// bit 15 14 13 12 11 10 9 8  7  6  5  4  3  2  1  0 POR
//      1  0  1  1  1  0 0 0 t7 t6 t5 t4 t3 t2 t1 t0 B8AAh
 #define CMD_TRANSMIT 0xB800

// This command is use to write a data byte in the TX-register and then RFM12 transmit it

//-----------------------------------------------
/*** Wake-Up Timer Command ***/

// bit 15 14 13 12 11 10  9  8  7  6  5  4  3  2  1  0 POR
//      1  1  1 r4 r3 r2 r1 r0 m7 m6 m5 m4 m3 m2 m1 m0 E196h
 #define CMD_WAKE_UP_TIME 0xE000

// The wake-up period is determined by:
// Time-wake-up = M * 2R [ms]

//-----------------------------------------------
/*** Low Duty-Cycle Command ***/

// bit 15 14 13 12 11 10 9 8  7  6  5  4  3  2  1  0 POR
//      1  1  0  0  1  0 0 0 d6 d5 d4 d3 d2 d1 d0 en C80Eh
 #define CMD_LOW_DUTY 0xC800

// [ d6..d0 ] -> Set duty cycle
// D.C.= (D * 2 +1) / M *100%

// [ en ] -> Enable low duty cycle mode
 #define EN_LOW_DUTY 0x0001

//-----------------------------------------------
/*** Low Battery Detector and Microcontroller Clock Divider Command ***/

// bit 15 14 13 12 11 10 9 8  7  6  5 4  3  2  1  0 POR
//      1  1  0  0  0  0 0 0 d2 d1 d0 0 v3 v2 v1 v0 C000h
 #define CMD_BATT_CLK_DIV 0xC000

// [ d2..d0 ] -> select frequency of CLK pin
// CLK signal is derive form crystal oscillator and it can be applied to MCU clock,
// to save a second crystal. If not used, please set bit [ dc ] to disable CLK output
// To integrate the load capacitor internal can not only save cost, but also adjust reference
// frequency by software
// d2  d1  d0  Clock frequency[MHz]
//  0   0   0  1
//  0   0   1  1.25
//  0   1   0  1.66
//  0   1   1  2
//  1   0   0  2.5
//  1   0   1  3.33
//  1   1   0  5
//  1   1   1  10
 #define CLK_PIN_FREQ_1    0x0000
 #define CLK_PIN_FREQ_1_25 0x0020
 #define CLK_PIN_FREQ_1_66 0x0040
 #define CLK_PIN_FREQ_2    0x0060
 #define CLK_PIN_FREQ_2_5  0x0080
 #define CLK_PIN_FREQ_3_33 0x00A0
 #define CLK_PIN_FREQ_5    0x00C0
 #define CLK_PIN_FREQ_10   0x00E0

// [ v3..v0 ] -> Set threshold voltage of Low battery detector
// Vlb = 2.2 + V * 0.1 [V]

//-----------------------------------------------
/*** Status Read Command ***/

// bit 15 14 13 12 11 10 9 8 7 6 5 4 3 2 1 0 POR
//      0  x  x  x  x  x x x x x x x x x x x -
 #define CMD_READ_STATUS 0x0000

// This command starts with a 0 and be used to read internal status register

//-----------------------------------------------

 #endif

//-----------------------------------------------
