;*** SPI.inc ***;
;------------------------------------------------
; Author: Torsten Knorr
; E-mail: create-soft@freenet.de
; copyright(C) 2016-2017 by Torsten Knorr
;------------------------------------------------

 .ifndef __RFM12BP_SPI__
 .equ    __RFM12BP_SPI__ = 1

 .include "RFM12BP.inc"

;------------------------------------------------

 .macro M_INIT_SPI

; Enable SPI, Master, set clock rate
    ldi  R_TEMP_L,      ((1 << SPE) | (1 << MSTR) | (1 << SPR0) | (1 << SPR1))
    out  SPCR,          R_TEMP_L

 .endmacro

;------------------------------------------------

 .macro M_SPI_WAIT_READY

 SPI_WAIT_READY_LOOP:
; Wait for transmission complete
    in   RI_SPSR,       SPSR
    sbrs RI_SPSR,       SPIF
    rjmp SPI_WAIT_READY_LOOP

 .endmacro

;------------------------------------------------

 .macro M_SPI_ENABLE

    ldi  R_TEMP_L,      ((1 << SPE) | (1 << MSTR) | (1 << SPR0) | (1 << SPR1))
    out  SPCR,          R_TEMP_L

 .endmacro

;------------------------------------------------

 .macro M_SPI_DISABLE

    clr  R_TEMP_L
    out  SPCR,          R_TEMP_L

 .endmacro

;------------------------------------------------

 .macro M_SPI_TRANSFER

    cbi  SPI_PORT,      SPI_SS

; Start transmission of data
    out  SPDR,          R_TEMP_H
    M_SPI_WAIT_READY
; store received data
    in   R_RXW_H,       SPDR

; Start transmission of data
    out  SPDR,          R_TEMP_L
    M_SPI_WAIT_READY
    in   R_RXW_L,       SPDR

    sbi  SPI_PORT,      SPI_SS

 .endmacro

;------------------------------------------------

 .macro M_SPI_MT_CMD

    ldi  R_TEMP_L,      low(@0)
    ldi  R_TEMP_H,      high(@0)

    M_SPI_TRANSFER

 .endmacro

;------------------------------------------------

 .macro M_SPI_MT_WORD

    ldi  R_TEMP_L,      low(@0)
    ldi  R_TEMP_H,      high(@0)

; Start transmission of data
    out  SPDR,          R_TEMP_H
    M_SPI_WAIT_READY
; store received data
    in   R_RXW_H,       SPDR

; Start transmission of data
    out  SPDR,          R_TEMP_L
    M_SPI_WAIT_READY
    in   R_RXW_L,       SPDR

 .endmacro

;------------------------------------------------

 .macro M_SPI_MT_BYTE

    ldi  R_TEMP_L,      @0

; Start transmission of data
    out  SPDR,          R_TEMP_L
    M_SPI_WAIT_READY
    in   R_RXW_L,       SPDR

 .endmacro

;------------------------------------------------

 .macro M_SPI_TX_CONFIG_1

    in   R_TEMP_L,      TX_CONFIG_1
    ldi  R_TEMP_H,      high(CMD_TX_CONFIG)

    M_SPI_TRANSFER

 .endmacro

;------------------------------------------------

 .macro M_SPI_TX_CONFIG_2

    in   R_TEMP_L,      TX_CONFIG_2
    ldi  R_TEMP_H,      high(CMD_TX_CONFIG)

    M_SPI_TRANSFER

 .endmacro

;------------------------------------------------

 .macro M_SPI_REMOTE_CMD

    lds  R_TEMP_L,      s_para_2
    lds  R_TEMP_L,      s_para_1

    M_SPI_TRANSFER

 .endmacro

;------------------------------------------------

 .endif

;------------------------------------------------
