;*** test.inc ***;
;------------------------------------------------
; Author: Torsten Knorr
; E-mail: create-soft@freenet.de
; copyright(C) 2016-2017 by Torsten Knorr
;------------------------------------------------

 .ifndef __RFM12BP_TEST__
 .equ    __RFM12BP_TEST__ = 1

 .include "RFM12BP.inc"

;------------------------------------------------

 .macro M_RFM12BP_TEST_SIGNAL

 TEST_LOOP:

    M_LED_DEBUG_1_ON
    sbi  PORTC,         RFM12BP_EN_TX

    M_SPI_MT_CMD (CMD_SET_FREQ   | @0)
    M_SPI_MT_CMD (CMD_TX_CONFIG  | OUTPUT_POWER_21 | FREQ_DEVIATION_30)
    M_SPI_MT_CMD (CMD_SET_POWER | EN_TX | EN_SYNTH | EN_CRYSTAL | DI_CLK_PIN)

    cbi  SPI_PORT,      SPI_SS

    M_SET_TIMER_1 TIME_6MS

 TEST_SIGNAL_LOOP:
    wdr

 TEST_SIGNAL_WAIT:
    sbis PIND,         RFM12BP_SDO
    rjmp TEST_SIGNAL_WAIT

    M_SPI_MT_WORD (CMD_TRANSMIT | @1)

    ;sbic STATUS_REG,    TIMER_1_RUN
    rjmp TEST_SIGNAL_LOOP

 TEST_WAIT_LAST_BYTE:
    sbis PINB,          SPI_MISO
    rjmp TEST_WAIT_LAST_BYTE

    sbi  SPI_PORT,      SPI_SS

    M_SPI_MT_CMD (CMD_SET_POWER | EN_SYNTH | EN_CRYSTAL | DI_CLK_PIN)

    cbi  PORTC,         RFM12BP_EN_TX
    M_LED_DEBUG_1_OFF

    M_SET_TIMER_1 0xFFFF ;TIME_1S
    M_WAIT_TIMER_1

    rjmp TEST_LOOP

 .endmacro

;------------------------------------------------

 .macro M_RFM12BP_TEST_ANTENNA

    M_SPI_MT_CMD (CMD_TX_CONFIG  | OUTPUT_POWER_21 | FREQ_DEVIATION_15)
    M_SPI_MT_CMD (CMD_SET_POWER | EN_TX | EN_SYNTH | EN_CRYSTAL | DI_CLK_PIN)

    ldi  R_COUNT_L,     0x60
    ldi  R_COUNT_H,     0x00

    ldi  R_TEMP_L,      0x3F
    ldi  R_TEMP_H,      0x0F
    movw R_DATA_L,      R_TEMP_L

    sbi  PORTC,         RFM12BP_EN_TX

 TEST_ANTENNA_LOOP:
    wdr

    ;ldi  R_TEMP_L,      0x3F
    ;ldi  R_TEMP_H,      0x0F
    cp   R_DATA_L,      R_COUNT_L
    cpc  R_DATA_H,      R_COUNT_H
    brsh NEXT_FREQUENCY

    ldi  R_COUNT_L,     0x60
    ldi  R_COUNT_H,     0x00

 NEXT_FREQUENCY:

    ;M_SPI_MT_CMD (CMD_READ_STATUS)
    movw R_TEMP_L,      R_COUNT_L
    ori  R_TEMP_H,      HIGH(CMD_SET_FREQ)
    M_SPI_TRANSFER

    ;M_SET_TIMER_1 TIME_1MS
    ;M_SET_TIMER_1 TIME_2MS
    ;M_SET_TIMER_1 TIME_6MS
    ;M_SET_TIMER_1 TIME_10MS
    ;M_SET_TIMER_1 TIME_200MS
    ;M_SET_TIMER_1 TIME_1S
    M_SET_TIMER_1 0xFFFF
    M_WAIT_TIMER_1

    adiw R_COUNT_L,     0x01
    rjmp TEST_ANTENNA_LOOP

 .endmacro

;------------------------------------------------

 .macro M_RFM12BP_TEST_DEVIATION

    sbi  PORTC,         RFM12BP_EN_TX

    M_SPI_MT_CMD (CMD_SET_FREQ   | @0)
    M_SPI_MT_CMD (CMD_TX_CONFIG  | OUTPUT_POWER_21 | FREQ_DEVIATION_45)
    M_SPI_MT_CMD (CMD_SET_POWER | EN_TX | EN_SYNTH | EN_CRYSTAL | DI_CLK_PIN)

    eor  R_TEST,        R_TEST
    ldi  R_COUNT_L,     0x88
    ldi  R_COUNT_H,     0x13
    cbi  SPI_PORT,      SPI_SS
 TEST_DEVIATION_LOOP:
    wdr

    sbiw R_COUNT_L,     0x01
    brne TEST_DEVIATION_WAIT

    sbi  SPI_PORT,      SPI_SS
    ldi  R_COUNT_L,     0x88
    ldi  R_COUNT_H,     0x13

    clr  R_TEMP_L
    cp   R_TEST,        R_TEMP_L
    breq TEST_DEVIATION_SET_60

    M_SPI_MT_CMD (CMD_TX_CONFIG  | OUTPUT_POWER_21 | FREQ_DEVIATION_45)
    eor  R_TEST,        R_TEST
    M_LED_DEBUG_1_ON
    M_LED_DEBUG_2_OFF
    cbi  SPI_PORT,      SPI_SS
    rjmp TEST_DEVIATION_WAIT

 TEST_DEVIATION_SET_60:
    M_SPI_MT_CMD (CMD_TX_CONFIG  | OUTPUT_POWER_21 | FREQ_DEVIATION_60)
    inc  R_TEST
    M_LED_DEBUG_1_OFF
    M_LED_DEBUG_2_ON
    cbi  SPI_PORT,      SPI_SS

 TEST_DEVIATION_WAIT:
    sbis PIND,         RFM12BP_SDO
    rjmp TEST_DEVIATION_WAIT

    M_SPI_MT_WORD (CMD_TRANSMIT | 0xAA)

    rjmp TEST_DEVIATION_LOOP

    M_SPI_MT_CMD (CMD_SET_POWER | EN_SYNTH | EN_CRYSTAL | DI_CLK_PIN)

    cbi  PORTC,         RFM12BP_EN_TX
    M_LED_DEBUG_1_OFF

 .endmacro

;------------------------------------------------

 .macro M_TEST_TRANSMIT

    ldi  R_PARA_L,      low(@0)
    ldi  R_PARA_H,      high(@0)
    ldi  R_ZP_L,        low(@1)
    ldi  R_ZP_H,        high(@1)

    movw R_COUNT_L,     R_ZP_L
    add  R_COUNT_L,     R_PARA_L
    adc  R_COUNT_H,     R_PARA_H

    ldi  R_TEMP_L,      0x01
 SET_RX_BUFF_LOOP:

    st   Z+,            R_TEMP_L

    inc  R_TEMP_L

; check pointer     >=
    cp   R_ZP_L,        R_COUNT_L
    cpc  R_ZP_H,        R_COUNT_H
    brlo SET_RX_BUFF_LOOP

 TEST_TRANSMIT_LOOP:

    M_LED_TX_ON
    M_RFM12BP_TRANSMIT @0, @1
    M_LED_TX_OFF

    M_SET_TIMER_1 0xFFFF
    M_WAIT_TIMER_1

    rjmp TEST_TRANSMIT_LOOP

 .endmacro

;------------------------------------------------

 .macro M_TEST_TIMER_2

 TEST_TIMER_2_LOOP:
    wdr

    M_SET_TIMER_2 38
    M_WAIT_TIMER_2
    M_LED_DEBUG_2_ON

    M_SET_TIMER_2 38
    M_WAIT_TIMER_2
    M_LED_DEBUG_2_OFF

    rjmp TEST_TIMER_2_LOOP

 .endmacro

;------------------------------------------------

 .macro M_TEST_TIMEOUT_TIMER_2

 TEST_TIMEOUT_TIMER_2_LOOP:

    M_LED_DEBUG_1_ON
    M_NOP_80
    rcall Function_1

    M_SET_TIMER_1 TIME_1S
    M_WAIT_TIMER_1

    rcall Function_2

    M_LED_DEBUG_1_OFF
    M_NOP_80

    rjmp TEST_TIMEOUT_TIMER_2_LOOP

 Function_1:

    M_SET_TIMER_2 0x27
    ;M_SET_TIMER_2 0x26 ; timeout

    ret

 Function_2:

    M_CHECK_TIMER_2
    rjmp NO_TEST_ACTION

    M_LED_DEBUG_2_ON
    M_NOP_80
    M_LED_DEBUG_2_OFF

    NO_TEST_ACTION:

    M_STOP_TIMER_2

    ret

 .endmacro

;------------------------------------------------

 .macro M_NOP_10

    nop
    nop
    nop
    nop
    nop
    nop
    nop
    nop
    nop
    nop

 .endmacro

;------------------------------------------------

 .macro M_NOP_20

    M_NOP_10
    M_NOP_10

 .endmacro

;------------------------------------------------

 .macro M_NOP_40

    M_NOP_20
    M_NOP_20

 .endmacro

;------------------------------------------------

 .macro M_NOP_80

    M_NOP_40
    M_NOP_40

 .endmacro

;------------------------------------------------

 .macro M_NOP_160

    M_NOP_80
    M_NOP_80

 .endmacro

;------------------------------------------------

 .macro M_NOP_320

    M_NOP_160
    M_NOP_160

 .endmacro

;------------------------------------------------

 .endif

;------------------------------------------------
