/*** WeatherStation.h ***/
//------------------------------------------------
// Author: Torsten Knorr
// E-mail: create-soft@freenet.de
// Copyright (c) 2017, Torsten Knorr
//------------------------------------------------

 #ifndef __WEATHER_STATION__
 #define __WEATHER_STATION__

//------------------------------------------------

 #define BOOL int

 #define PORT_PU_ON  1
 #define PORT_PU_OFF 0

 #define PORT_HIGH 1
 #define PORT_LOW  0

 #define HI_CHAR(a) ((((a)%100)/10)+0x30)
 #define LOW_CHAR(a) (((a)%10)+0x30)

 #define BCD_TO_CHAR_H(a) (((a)>>4)+0x30)
 #define BCD_TO_CHAR_L(a) (((a)&0x0F)+0x30)

 #define BCD_TO_VALUE(a) ((((a)>>4)*0x0A)+((a)&0x0F))

//-----------------------------------------------
/*** Thread Definitions ***/

 #define THREAD_MAIN 0
 #define THREAD_KEYBOARD 1
 #define THREAD_DISPLAY 2
 #define SIG_DCF77 0x10
 #define SIG_KEYBOARD 0x20
 #define SIG_DISPLAY 0x30

 #define LOCK   1
 #define UNLOCK 0

 #thread THREAD_MAIN, 0, 20
 #thread THREAD_KEYBOARD, 4095, 5
 #thread THREAD_DISPLAY, 4095, 5

//-----------------------------------------------
/*** Keyboard Definitions ***/

// #define KEY_3 1 // value
   #define KEY_3 1 // bit position

// #define KEY_6 2
   #define KEY_6 2

// #define KEY_9 4
   #define KEY_9 3

// #define KEY_2 8
   #define KEY_2 4

// #define KEY_V1 16
   #define KEY_V1  5

// #define KEY_V2 32
   #define KEY_V2  6

// #define KEY_V3 64
   #define KEY_V3  7

// #define KEY_V4 128
   #define KEY_V4   8

// #define KEY_8  256
   #define KEY_8    9

// #define KEY_0  512
   #define KEY_0   10

// #define KEY_4 1024
   #define KEY_4   11

// #define KEY_X 2048
   #define KEY_X   12

// #define KEY_7 4096
   #define KEY_7   13

// #define KEY_1 8192
   #define KEY_1   14

// #define KEY_5 16384
   #define KEY_5    15

// #define KEY_H 32768
   #define KEY_H    16

//-----------------------------------------------
/*** LCD Definitions ***/

 #define LCD_DELAY 2

// LCD-Instructions

// Clear display
// Clears entire display and sets DDRAM address 0 in address counter.
 #define LCD_CLEAR          0x01

// Return home
// Sets DDRAM address 0 in address counter. Also returns display from
// being shifted to original position. DDRAM contents remain unchanged.
 #define LCD_RETURN         0x02

// Entry mode set
// Sets cursor move direction and specifies display shift. These operations
// are performed during data write and read.
 #define LCD_MODE           0x04
 #define CURSOR_MOVE_RIGHT  0x02
 #define CURSOR_MOVE_LEFT   0x00
 #define AUTO_SHIFT_ENABLE  0x01
 #define AUTO_SHIFT_DISABLE 0x00

// Display on/off control
// Sets entire display (D) on/off, cursor on/off (C), and blinking of cursor
// position character (B).
 #define LCD_CONTROL        0x08
 #define DISPLAY_ON         0x04
 #define DISPLAY_OFF        0x00
 #define CURSOR_ON          0x02
 #define CURSOR_OFF         0x00
 #define BLINKING_ON        0x01
 #define BLINKING_OFF       0x00

// Cursor or display shift
// Moves cursor and shifts display without changing DDRAM contents.
 #define LCD_SHIFT          0x10
 #define SHIFT_DISPLAY      0x08
 #define SHIFT_CURSOR       0x00
 #define SHIFT_RIGHT        0x04
 #define SHIFT_LEFT         0x00

// Function set
// Sets interface data length (DL), number of display lines (N),
// and character font (F).
 #define LCD_SET            0x20
 #define INTERFACE_8_BITS   0x10
 #define INTERFACE_4_BITS   0x00
 #define TWO_LINES          0x08
 #define ONE_LINE           0x00
 #define 5_X_10_DOTS        0x04
 #define 5_X_8_DOTS         0x00

// Set CGRAM address
// Sets CGRAM address. CGRAM data is sent and received after this setting.
 #define LCD_CGRAM          0x40

// Set DDRAM address
// Sets DDRAM address. DDRAM data is sent and received after this setting.
 #define LCD_DDRAM          0x80

//-----------------------------------------------
/*** Port Definitions ***/

// DCF Input Signal at PortF.0
 #define DCF_IN        0x28
 #define SD_CARD_LED   0x29
 #define RELAY_1       0x2A
 #define RELAY_2       0x2B
 #define RAINFALL_PORT 0x2C
 #define CT63_ON       0x2D
 #define CT63_RING_IN  0x2E
 #define CT63_OFF      0x2F

//------------------------------------------------
/*** DCF77 Time Definitions ***/

 #define MINUTE 0
 #define HOUR 1
 #define DAY 2
 #define WEEKDAY 3
 #define MONTH 4
 #define YEAR 5
 #define DCF_SIZE 8
 #define BCD_SIZE 6
 #define VALUES_SIZE 6
 #define WEEKDAYS 8
 #define WEEKDAY_LENGTH 11
// #define MSG_LENGTH 35
 #define MSG_LENGTH 20
 #define DATE_LENGTH 11
 #define ERROR_MSG_LENGTH 20

//------------------------------------------------
/*** I2C address ***/

// temp 1 outside             0b1001 1110
// #define TEMP_1_OUT_ADDR      0x9E
// temp 2 inside              0b1001 1100
// #define TEMP_2_IN_ADDR       0x9C
// temp 3 earth 10 cm         0b0011 0000
 #define TEMP_3_EARTH_10_ADDR 0x30
// temp 4 earth 20cm          0b0011 0010
 #define TEMP_4_EARTH_20_ADDR 0x32
// RFM12BP
 #define RFM12BP_ADDR         (0x71 << 1)
 #define RTC_ADDR             0xD0
// rainfall
// air humidity inside
 #define HUMIDITY_IN_ADDR     (0x79 << 1)
// air humidity outside
 #define HUMIDITY_OUT_ADDR    (0x7A << 1)
// pressure
 #define PRESSURE_ADDR        (0x7B << 1)

//------------------------------------------------
/*** CT63 Terminal Definitions ***/

// #define CT63_ON       0x2D
// #define CT63_RING_IN  0x2E
// #define CT63_OFF      0x2F
 #define CT63_SERIAL_PORT 0

//-----------------------------------------------
/*** RFM12BP Definitions ***/

 #define ID_BYTE_1            192
 #define ID_BYTE_2            168
 #define ID_BYTE_3            100
 #define ID_BYTE_4            001

 #define RFM12BP_ID_SIZE    0x04
 #define RFM12BP_TIME_SIZE  0x06
 #define RFM12BP_CMD_SIZE   0x01
 #define RFM12BP_PARA_SIZE  0x02
 #define RFM12BP_DATA_SIZE  0x40
 #define RFM12BP_CRC_SIZE   0x01
 #define RFM12BP_BUFF_SIZE  (RFM12BP_ID_SIZE  +\
                            RFM12BP_TIME_SIZE +\
                            RFM12BP_CMD_SIZE  +\
                            RFM12BP_PARA_SIZE +\
                            RFM12BP_DATA_SIZE +\
                            RFM12BP_CRC_SIZE)

 #define RFM12BP_REQUEST_SIZE   (RFM12BP_ID_SIZE  +\
                                RFM12BP_TIME_SIZE +\
                                RFM12BP_CMD_SIZE  +\
                                RFM12BP_PARA_SIZE)

 #define RFM12BP_VALUES_COUNT  0x10

 #define RFM12BP_TEMP_OUTSIDE     0x00
 #define RFM12BP_TEMP_INSIDE      0x01
 #define RFM12BP_TEMP_EARTH_10    0x02
 #define RFM12BP_TEMP_EARTH_20    0x03
 #define RFM12BP_RAINFALL         0x04
 #define RFM12BP_LEVEL            0x05
 #define RFM12BP_GROUND_MOISTURE  0x06
 #define RFM12BP_HUMIDITY_OUTSIDE 0x07
 #define RFM12BP_HUMIDITY_INSIDE  0x08
 #define RFM12BP_PRESSURE         0x09
 #define RFM12BP_WIND_FORCE       0x0A
 #define RFM12BP_WIND_DIRECTION   0x0B
 #define RFM12BP_OPERATION_HOURS  0x0C
 #define RFM12BP_RAINFALL_FR_STOP 0x0D
 #define RFM12BP_ERRORS_COUNT     0x0E
 #define RFM12BP_I2C_ERRORS       0x0F

 #define RFM12BP_CMD_GET          0x00
 #define RFM12BP_CMD_CMD          0x01
 #define RFM12BP_CMD_EXE          0x02
 #define RFM12BP_CMD_RES          0x03
 #define RFM12BP_CMD_TEST         0x04

 #define PARA_OUTPUT_POWER_1      0x01
 #define PARA_OUTPUT_POWER_2      0x02
 #define PARA_FREQ_DEVIATION_1    0x03
 #define PARA_FREQ_DEVIATION_2    0x04
 #define PARA_TH_DQD              0x05

 #define RFM12BP_NOP              0x00
 #define RFM12BP_CONF_OUT_1       0x01
 #define RFM12BP_CONF_OUT_2       0x02
 #define RFM12BP_CONF_DEV_1       0x03
 #define RFM12BP_CONF_DEV_2       0x04
 #define RFM12BP_CONF_BBW         0x05
 #define RFM12BP_CONF_LNAG        0x06
 #define RFM12BP_CONF_DRSSI       0x07
 #define RFM12BP_CONF_DQD         0x08
 #define RFM12BP_CONFIRM          0x09
 #define RFM12BP_EXE_CMD          0x0A
 #define RFM12BP_LOAD_DEF         0x0B
 #define RFM12BP_MODUL_RES        0x0C
 #define RFM12BP_COMPL_RES        0x0D
 #define TEST_LEDS                0x0E
 #define TEST_LED_DEBUG_1         0x0F
 #define TEST_LED_DEBUG_2         0x10
 #define RFM12BP_END              0x11

 #define RFM12BP_CMD_MASK         0x3F

 #define RFM12BP_REMOTE_CMD       0x80
 #define RFM12BP_LOCAL_CMD        0x40

//-----------------------------------------------
/*** RTC_DS1339U.cc ***/

 #define RTC_SEC  0x00
 #define RTC_MIN  0x01
 #define RTC_HOUR 0x02
 #define RTC_DOW  0x03 // Day of Week unused
 #define RTC_DAY  0x04
 #define RTC_MON  0x05
 #define RTC_YEAR 0x06

 #define SIZE_OF_RTC_TIME 7

//-----------------------------------------------
/*** Data Collect Definitions ***/

 #define TEMP_OUTSIDE      0
 #define TEMP_INSIDE       4
 #define TEMP_EARTH_10     8
 #define TEMP_EARTH_20    12
 #define RAINFALL         16
 #define PRESSURE         20
 #define HUMIDITY_OUTSIDE 24
 #define HUMIDITY_INSIDE  28

 #define COUNT_VALUES    96
 #define STEP_VALUE      32
 #define SIZE_VALUE       4
 #define LAST_POSITION 3068

// 4 x 31 = 124
 #define DECADE_POSITION          3072
 #define DECADE_TEMP_OUTSIDE_MIN  3072
 #define DECADE_TEMP_OUTSIDE_MAX  3196
 #define DECADE_TEMP_INSIDE_MIN   3320
 #define DECADE_TEMP_INSIDE_MAX   3444
 #define DECADE_TEMP_EARTH_10_MIN 3568
 #define DECADE_TEMP_EARTH_20_MIN 3692
 #define DECADE_RAINFALL_SUM      3816
 #define DECADE_LAST_POSITION     3936

 #define OPERATION_HOURS          3940
 #define RAINFALL_FROST_STOP      3944

 #define DECADE_1 10
 #define DECADE_2 20
 #define DECADE_3 0

//------------------------------------------------
/*** Relay Card Definitions ***/

// #define RELAY_1       0x2A
// #define RELAY_2       0x2B

//------------------------------------------------
/*** Level Definitions ***/

 #define LEVEL_PORT 44
 #define LEVEL_VALUE_4mA 0.0
 #define LEVEL_VALUE_20mA 200.0
 #define LEVEL_VALUE_RANGE (LEVEL_VALUE_20mA - LEVEL_VALUE_4mA)
 #define LEVEL_INPUT_MAX 798.0
 #define LEVEL_INPUT_MIN 156.0
 #define LEVEL_INPUT_RANGE (LEVEL_INPUT_MAX - LEVEL_INPUT_MIN)
 #define LEVEL_SCALE_OFFSET 46.00
 #define LEVEL_FACTOR (LEVEL_VALUE_RANGE / LEVEL_INPUT_RANGE)

//------------------------------------------------
/*** Rainfall Definitions ***/

 #define RAINFALL_PORT 44
 #define RAINFALL_VALUE_4mA 0.0
 #define RAINFALL_VALUE_20mA 200.0
 #define RAINFALL_RANGE (RAINFALL_VALUE_20mA - RAINFALL_VALUE_4mA)
 #define RAINFALL_INPUT_MAX 798.0
 #define RAINFALL_INPUT_MIN 156.0
 #define RAINFALL_INPUT_RANGE (RAINFALL_INPUT_MAX - RAINFALL_INPUT_MIN)
 #define RAINFALL_FACTOR 0.2339047
 #define RAINFALL_MAX_DIFF 10
 #define RAINFALL_SCALE_OFFSET 25.0

//------------------------------------------------
/*** Menu Definitions ***/

 #define MENU_CLOCK        0
 #define MENU_RFM12BP      1
 #define MENU_SET_PARA     2
 #define MENU_VALUES_TEMP  3
 #define MENU_VALUES_HUM   4
 #define MENU_VALUES_AIR   5
 #define MENU_STATE        6

 #define MENU_COUNT        7
//------------------------------------------------
/*** Display Definitions ***/

 #define DISPLAY_CLEAR_MEMORY     0x13
 #define DISPLAY_TEST_SMS         0x14
 #define DISPLAY_DATA_REQUEST     0x15
 #define DISPLAY_INSERT_ID        0x16
 #define DISPLAY_INSERT_CMD       0X17
 #define DISPLAY_AREA_EXE         0x19
 #define DISPLAY_PARA_NUM         0x1A
 #define DISPLAY_SET_TIME         0x1B

 #define DISPLAY_CLOCK            0x00
 #define DISPLAY_VALUE            0x01
 #define DISPLAY_LINE_1           0x02
 #define DISPLAY_LINE_2           0x03
 #define DISPLAY_MSG              0x04
 #define DISPLAY_INSERT           0x05
 #define DISPLAY_MOVE_TEXT        0x06

 #define DISPLAY_OUT_OF_RANGE     0x10
 #define DISPLAY_UNDEF_KEY        0x11

 #define DISPLAY_STOP             0x20

 #define SET_DISPLAY_MSG(a,b,c) \
Thread_Lock(LOCK);\
gi_display_mode=DISPLAY_MSG;\
Str_Copy(gac_line_1,a,0);\
Str_Copy(gac_line_2,b,0);\
gw_thread_delay=c;\
Thread_Lock(UNLOCK);\
Thread_Start(THREAD_DISPLAY,ThreadDisplay);\
Thread_Delay(c);

 #define SET_DISPLAY_MODE(a) \
Thread_Lock(LOCK);\
gi_display_mode=a;\
Thread_Lock(UNLOCK);\
Thread_Start(THREAD_DISPLAY,ThreadDisplay);

 #define SET_DISPLAY_MOVE(a,b) \
Thread_Lock(LOCK);\
gi_display_mode=DISPLAY_MOVE_TEXT;\
gac_line_1=a;\
gac_line_2=b;\
Thread_Lock(UNLOCK);\
Thread_Start(THREAD_DISPLAY,ThreadDisplay);

 #define SET_DISPLAY_VALUE(a,b) \
Thread_Lock(LOCK);\
gi_display_mode=DISPLAY_VALUE;\
gac_line_1=a;\
gf_value=gaf_values[b];\
Thread_Lock(UNLOCK);\
Thread_Start(THREAD_DISPLAY,ThreadDisplay);

 #define SET_DISPLAY_ERROR(a,b) \
Thread_Lock(LOCK);\
gi_display_mode=a;\
Thread_Lock(UNLOCK);\
Thread_Start(THREAD_DISPLAY,ThreadDisplay);\
gbo_display_change=true;\
Thread_Delay(b);

 #define SET_DISPLAY_INSERT(a,b) \
Thread_Lock(LOCK);\
gi_display_mode=DISPLAY_INSERT;\
gac_line_1=a;\
gac_line_2=b;\
Thread_Lock(UNLOCK);\
Thread_Start(THREAD_DISPLAY,ThreadDisplay);

//------------------------------------------------
/*** SD-Card Definitions ***/

 #define SD_CARD_SS   0x08 // PB.0
 #define SD_CARD_SCK  0x09 // PB.1
 #define SD_CARD_MOSI 0x0A // PB.2
 #define SD_CARD_MISO 0x0B // PB.3
 #define SD_CARD_CD   0x0C // PB.4
 #define SD_CARD_EN1  0x0D // PB.5
 #define SD_CARD_EN2  0x0E // PB.6
 #define SD_CARD_WP   0x25 // PE.5
 #define SD_CARD_LED  0x29 // PF.1
 #define SD_CARD_ERR_CD 0x11
 #define SD_CARD_ERR_WP 0x12

//------------------------------------------------
/*** Error Treatment ***/

 #define ITEMS_COUNT 10
 #define INVALID_VALUE 210.0
 #define MAX_VALUE 105.0
 #define MIN_VALUE -35.0
 #define ERRORS_TEMP_OUTSIDE     0
 #define ERRORS_TEMP_INSIDE      1
 #define ERRORS_TEMP_EARTH_10    2
 #define ERRORS_TEMP_EARTH_20    3
 #define ERRORS_RAINFALL         4
 #define ERRORS_PRESSURE         5
 #define ERRORS_HUMIDITY_OUTSIDE 6
 #define ERRORS_HUMIDITY_INSIDE  7
 //#define ERRORS_EARTH_HUMIDITY   8
 #define ERRORS_LEVEL            9
 #define MAX_ERRORS 5

//------------------------------------------------

 #define LED_ON  0x00
 #define LED_OFF 0x01

//------------------------------------------------
 #endif
//------------------------------------------------